@@ -146,7 +146,7 @@ private:
         while (begin != end)
         {
             x = *begin;
-            if ( ('0' <= x && x <= '9') || x == '.')
+            if ( ('0' <= x && x <= '9') || x == '.' || x == '-')
             {
                 begin++;
             }
